==> prestashop_1.5.0.2.zip: prestashop/translations/fr/fields.php <==
<?php

global $_FIELDS;
$_FIELDS = array();
$_FIELDS['AddressFormat_1ddcb92ade31c8fbd370001f9b29a7d9'] = 'format';
$_FIELDS['Configuration_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Configuration_c79c16c41a33108866a9a4c785c73f4f'] = 'ID de groupe de la boutique';
$_FIELDS['Configuration_5a0971a207e75dd040db8b6a3425a8bf'] = 'ID de la boutique';
$_FIELDS['Configuration_ab332097a7a287c9e711aba495c44e9e'] = 'date d\'ajout';
$_FIELDS['Configuration_6e3005e36b07fd014f7123b0fe039628'] = 'date de modification';
$_FIELDS['Country_efc19cceda447c9d6f95094e9b01ef24'] = 'ID de la zone';
$_FIELDS['Country_d488c3bb8b7a06f26e44c153ce047933'] = 'ID de la devise';
$_FIELDS['Country_3011322530410f26aa0f8066e68c7070'] = 'Prefix d\'appel international';
$_FIELDS['Country_213ecf1210f43736b6d4997fcfa27954'] = 'code ISO';
$_FIELDS['Country_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Country_0fac5b779177ce96171a0b7d6f686200'] = 'contient des états';
$_FIELDS['Country_1a1ca79d4710078f654cd88b3311a80a'] = 'besoin d\'un numéro d\'identification';
$_FIELDS['Country_1034ac1cb822c1e040fe45ffc028f38d'] = 'Requiert un code postal';
$_FIELDS['Country_37f577d6d447ff0743d74245446223b3'] = 'Format du code postal';
$_FIELDS['Country_514b22ce3e77a7badaf3da0c712e64d5'] = 'Afficher le champ des taxes';
$_FIELDS['Country_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Currency_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Currency_213ecf1210f43736b6d4997fcfa27954'] = 'iso_code';
$_FIELDS['Currency_0277df6625def0af560c3b99b581d63d'] = 'iso_code_num';
$_FIELDS['Currency_8e15625d6c158ec48f374efb77bd2714'] = 'espace';
$_FIELDS['Currency_04b29480233f4def5c875875b6bdc3b1'] = 'symbole';
$_FIELDS['Currency_1ddcb92ade31c8fbd370001f9b29a7d9'] = 'format';
$_FIELDS['Currency_7b0e9073e0ace5be202843a759dc15ce'] = 'décimales';
$_FIELDS['Currency_393b71c52a4e802dc2a598d2e0a437b8'] = 'taux de conversion';
$_FIELDS['Currency_da602f0b162fccbf6b150cfcfc7a7379'] = 'supprimé';
$_FIELDS['Currency_c76a5e84e4bdee527e274ea30c680d79'] = 'activation';
$_FIELDS['Employee_8ad75c5a8821cc294f189181722acb56'] = 'Nom';
$_FIELDS['Employee_342f5c77ed008542e78094607ce1f7f3'] = 'Prénom';
$_FIELDS['Employee_0c83f57c786a0b4a39efab23731c7ebc'] = 'e-mail';
$_FIELDS['Employee_2241013f64d89954e85e6285f0c6b85b'] = 'ID de langue';
$_FIELDS['Employee_76a2173be6393254e72ffa4d6df1030a'] = 'mot de passe';
$_FIELDS['Employee_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Employee_7d33fcc514e7c41792b26c9782103f73'] = 'ID du profil';
$_FIELDS['Employee_19bd0ea6d7e46a8f82a0278c2175e57c'] = 'Couleur du back office';
$_FIELDS['Employee_a5253b4a2c85873f246fe02468c03064'] = 'Thème du back office';
$_FIELDS['Employee_4a46552472dbbe599b1029b338c78868'] = 'Montrer la vidéo d\'accueil';
$_FIELDS['Employee_0a73cf7c516be1d02a8f54f90f0170b6'] = 'Date de début des statistiques';
$_FIELDS['Employee_8b67f597f77491fff038d57573bb8718'] = 'Date de fin des statistiques';
$_FIELDS['Hook_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Language_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Language_213ecf1210f43736b6d4997fcfa27954'] = 'code ISO';
$_FIELDS['Language_60716c2f59efe423380e2faeb03472d5'] = 'language_code';
$_FIELDS['Language_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Language_72297458b7dd56f4fed7ad50f8f92528'] = 'is_rtl';
$_FIELDS['Language_bcc3919a88718453b7b718da20fa743e'] = 'date_format_lite';
$_FIELDS['Language_04d2a887193db1373552504a6cff0bbb'] = 'date_format_full';
$_FIELDS['Product_1e11810933474f450c5a5ed9d091ad54'] = 'id_tax_rules_group';
$_FIELDS['Product_98305bfa557ba2547e7de1fb77053c93'] = 'ID du fabricant';
$_FIELDS['Product_ad8a1593fb8fbba0eb0f9dba0e51e7f1'] = 'ID du fournisseur';
$_FIELDS['Product_8d336d1978082d3391ee800843ae7cde'] = 'catégorie par défaut';
$_FIELDS['Product_4528f3a77f21b742999a942749e76b5b'] = 'Quantité minimale';
$_FIELDS['Product_78a5eb43deef9a7b5b9ce157b9d52ac4'] = 'prix';
$_FIELDS['Product_45b47700c89cd2373c349d2cf1da8677'] = 'Coût du transporteur additionnel';
$_FIELDS['Product_df0a2c1d8d1182b8d821a4d2234fd759'] = 'prix d\'achat';
$_FIELDS['Product_6d799c235554e1d07290735fb9b3f6f0'] = 'en solde';
$_FIELDS['Product_04fb94825747b47eb12a2c355be5cab2'] = 'En ligne seulement';
$_FIELDS['Product_ae10d61c45ba89be06639c38776f612d'] = 'eco-participation';
$_FIELDS['Product_439b3a25b555b3bc8667a09a036ae70c'] = 'Unité';
$_FIELDS['Product_b8af13ea9c8fe890c9979a1fa8dbde22'] = 'référence';
$_FIELDS['Product_1950fdff13af2490fd97a0c7943c61c0'] = 'référence du fournisseur';
$_FIELDS['Product_d5189de027922f81005951e6efe0efd5'] = 'emplacement';
$_FIELDS['Product_eaae26a6fb20ed3ef54fb23bfa0b1fcc'] = 'largeur';
$_FIELDS['Product_b435e227d5dd201e1768b2bcb2e0aa81'] = 'hauteur';
$_FIELDS['Product_12a055bf01a31369fe81ac35d85c7bc1'] = 'profondeur';
$_FIELDS['Product_7edabf994b76a00cbc60c95af337db8f'] = 'poids';
$_FIELDS['Product_cbf60d83e435e1839455ce0706874d13'] = 'quantité de réduction ';
$_FIELDS['Product_a4878e4653eb71448e5d91923e400870'] = 'personnalisable';
$_FIELDS['Product_8cae40662e44cd61cfe1453cde9798c9'] = 'fichier uploadé';
$_FIELDS['Product_24405099e3dda731635b5ffac0452284'] = 'champs texte';
$_FIELDS['Product_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Product_a8f037501ece7a72a4eabfa2e01c8dd7'] = 'Disponible à la vente';
$_FIELDS['Product_a80df855bb6ec792a6bd2f4260dc7c7d'] = 'Date de disponibilité';
$_FIELDS['Product_3f9178c25b78ed8bed19091bcb62e266'] = 'Condition';
$_FIELDS['Product_f502f8d11a77413b4f273cd601f2b363'] = 'affichage du prix';
$_FIELDS['Product_a3b6a4d0897451813950029a3066f219'] = 'EAN 13';
$_FIELDS['Product_2f9e567efb6a38663162f65eaac2d73b'] = 'UPC';
$_FIELDS['Product_7efb96e1de8fcda98dee6e2a29a521f0'] = 'indexé';
$_FIELDS['Product_21597fd76e73b8c9ee8255fa26c35c80'] = 'cache_is_pack';
$_FIELDS['Product_cfeadf6a60808e5ffeff8268bec49bb6'] = 'is_virtual';
$_FIELDS['Product_98f3e6fb2a32fce35b5243f090cb4b87'] = 'cache_has_attachments';
$_FIELDS['Product_ab332097a7a287c9e711aba495c44e9e'] = 'date d\'ajout';
$_FIELDS['Product_6e3005e36b07fd014f7123b0fe039628'] = 'date de modification';
$_FIELDS['Product_1d549d55228eafc5a0d8b4e9e46b1692'] = 'gestion avancé des stocks';
$_FIELDS['Product_daed73073d15e0baf1cdfaea3b5e28ab'] = 'meta description';
$_FIELDS['Product_69a2fc764784fa41975b85e0aa96ded3'] = 'meta mots-clefs';
$_FIELDS['Product_493c8b960a4aca4d102deaf489d5b3f4'] = 'balise <title>';
$_FIELDS['Product_a2c6a4f5547c18f5b19a2a89569ab4e5'] = 'URL simplifiée';
$_FIELDS['Product_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Product_67daf92c833c41c95db874e18fcb2786'] = 'description';
$_FIELDS['Product_0f7431650cc1691fbe92dc2cbb70e476'] = 'description courte';
$_FIELDS['Product_b00f6b4f92d22056f98d0c5e72367a4c'] = 'disponibilité immédiate';
$_FIELDS['Product_7ebd308f48331aecb63ddc9dc0f1b9b8'] = 'disponibilité future';
$_FIELDS['Profile_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['QuickAccess_2a304a1348456ccd2234cd71a81bd338'] = 'lien';
$_FIELDS['QuickAccess_48df2d0e8fcf6f9fe7809d5ea0cd2691'] = 'nouvelle_fenêtre';
$_FIELDS['QuickAccess_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Tab_672070865d6470b0b9c251e275faaa30'] = 'ID de l\'onglet mère';
$_FIELDS['Tab_4757fe07fd492a8be0ea6a760d683d6e'] = 'position';
$_FIELDS['Tab_22884db148f0ffb0d830ba431102b0b5'] = 'module';
$_FIELDS['Tab_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Tab_b068931cc450442b63f5b3d276ea4297'] = 'nom';

?>

==> prestashop_1.5.0.3.zip: prestashop/translations/fr/fields.php <==
<?php

global $_FIELDS;
$_FIELDS = array();
$_FIELDS['CMSCategory_b068931cc450442b63f5b3d276ea4297'] = 'Nom';
$_FIELDS['Configuration_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Configuration_c79c16c41a33108866a9a4c785c73f4f'] = 'ID de groupe de la boutique';
$_FIELDS['Configuration_5a0971a207e75dd040db8b6a3425a8bf'] = 'ID de la boutique';
$_FIELDS['Configuration_ab332097a7a287c9e711aba495c44e9e'] = 'date d\'ajout';
$_FIELDS['Configuration_6e3005e36b07fd014f7123b0fe039628'] = 'date de modification';
$_FIELDS['Country_efc19cceda447c9d6f95094e9b01ef24'] = 'ID de la zone';
$_FIELDS['Country_d488c3bb8b7a06f26e44c153ce047933'] = 'ID de la devise';
$_FIELDS['Country_3011322530410f26aa0f8066e68c7070'] = 'Prefix d\'appel international';
$_FIELDS['Country_213ecf1210f43736b6d4997fcfa27954'] = 'code ISO';
$_FIELDS['Country_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Country_0fac5b779177ce96171a0b7d6f686200'] = 'contient des états';
$_FIELDS['Country_1a1ca79d4710078f654cd88b3311a80a'] = 'besoin d\'un numéro d\'identification';
$_FIELDS['Country_1034ac1cb822c1e040fe45ffc028f38d'] = 'Requiert un code postal';
$_FIELDS['Country_37f577d6d447ff0743d74245446223b3'] = 'Format du code postal';
$_FIELDS['Country_514b22ce3e77a7badaf3da0c712e64d5'] = 'Afficher le champ des taxes';
$_FIELDS['Country_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Currency_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Currency_213ecf1210f43736b6d4997fcfa27954'] = 'iso_code';
$_FIELDS['Currency_0277df6625def0af560c3b99b581d63d'] = 'iso_code_num';
$_FIELDS['Currency_8e15625d6c158ec48f374efb77bd2714'] = 'espace';
$_FIELDS['Currency_04b29480233f4def5c875875b6bdc3b1'] = 'symbole';
$_FIELDS['Currency_1ddcb92ade31c8fbd370001f9b29a7d9'] = 'format';
$_FIELDS['Currency_7b0e9073e0ace5be202843a759dc15ce'] = 'décimales';
$_FIELDS['Currency_393b71c52a4e802dc2a598d2e0a437b8'] = 'taux de conversion';
$_FIELDS['Currency_da602f0b162fccbf6b150cfcfc7a7379'] = 'supprimé';
$_FIELDS['Currency_c76a5e84e4bdee527e274ea30c680d79'] = 'activation';
$_FIELDS['Employee_8ad75c5a8821cc294f189181722acb56'] = 'Nom';
$_FIELDS['Employee_342f5c77ed008542e78094607ce1f7f3'] = 'Prénom';
$_FIELDS['Employee_0c83f57c786a0b4a39efab23731c7ebc'] = 'e-mail';
$_FIELDS['Employee_2241013f64d89954e85e6285f0c6b85b'] = 'ID de langue';
$_FIELDS['Employee_76a2173be6393254e72ffa4d6df1030a'] = 'mot de passe';
$_FIELDS['Employee_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Employee_7d33fcc514e7c41792b26c9782103f73'] = 'ID du profil';
$_FIELDS['Employee_19bd0ea6d7e46a8f82a0278c2175e57c'] = 'Couleur du back office';
$_FIELDS['Employee_a5253b4a2c85873f246fe02468c03064'] = 'Thème du back office';
$_FIELDS['Employee_4a46552472dbbe599b1029b338c78868'] = 'Montrer la vidéo d\'accueil';
$_FIELDS['Employee_0a73cf7c516be1d02a8f54f90f0170b6'] = 'Date de début des statistiques';
$_FIELDS['Employee_8b67f597f77491fff038d57573bb8718'] = 'Date de fin des statistiques';
$_FIELDS['Hook_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Language_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Language_213ecf1210f43736b6d4997fcfa27954'] = 'code ISO';
$_FIELDS['Language_60716c2f59efe423380e2faeb03472d5'] = 'language_code';
$_FIELDS['Language_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Language_72297458b7dd56f4fed7ad50f8f92528'] = 'is_rtl';
$_FIELDS['Language_bcc3919a88718453b7b718da20fa743e'] = 'date_format_lite';
$_FIELDS['Language_04d2a887193db1373552504a6cff0bbb'] = 'date_format_full';
$_FIELDS['Product_1e11810933474f450c5a5ed9d091ad54'] = 'id_tax_rules_group';
$_FIELDS['Product_98305bfa557ba2547e7de1fb77053c93'] = 'ID du fabricant';
$_FIELDS['Product_ad8a1593fb8fbba0eb0f9dba0e51e7f1'] = 'ID du fournisseur';
$_FIELDS['Product_8d336d1978082d3391ee800843ae7cde'] = 'catégorie par défaut';
$_FIELDS['Product_4528f3a77f21b742999a942749e76b5b'] = 'Quantité minimale';
$_FIELDS['Product_78a5eb43deef9a7b5b9ce157b9d52ac4'] = 'prix';
$_FIELDS['Product_45b47700c89cd2373c349d2cf1da8677'] = 'Coût du transporteur additionnel';
$_FIELDS['Product_df0a2c1d8d1182b8d821a4d2234fd759'] = 'prix d\'achat';
$_FIELDS['Product_6d799c235554e1d07290735fb9b3f6f0'] = 'en solde';
$_FIELDS['Product_04fb94825747b47eb12a2c355be5cab2'] = 'En ligne seulement';
$_FIELDS['Product_ae10d61c45ba89be06639c38776f612d'] = 'eco-participation';
$_FIELDS['Product_439b3a25b555b3bc8667a09a036ae70c'] = 'Unité';
$_FIELDS['Product_b8af13ea9c8fe890c9979a1fa8dbde22'] = 'référence';
$_FIELDS['Product_1950fdff13af2490fd97a0c7943c61c0'] = 'référence du fournisseur';
$_FIELDS['Product_d5189de027922f81005951e6efe0efd5'] = 'emplacement';
$_FIELDS['Product_eaae26a6fb20ed3ef54fb23bfa0b1fcc'] = 'largeur';
$_FIELDS['Product_b435e227d5dd201e1768b2bcb2e0aa81'] = 'hauteur';
$_FIELDS['Product_12a055bf01a31369fe81ac35d85c7bc1'] = 'profondeur';
$_FIELDS['Product_7edabf994b76a00cbc60c95af337db8f'] = 'poids';
$_FIELDS['Product_cbf60d83e435e1839455ce0706874d13'] = 'quantité de réduction ';
$_FIELDS['Product_a4878e4653eb71448e5d91923e400870'] = 'personnalisable';
$_FIELDS['Product_8cae40662e44cd61cfe1453cde9798c9'] = 'fichier uploadé';
$_FIELDS['Product_24405099e3dda731635b5ffac0452284'] = 'champs texte';
$_FIELDS['Product_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Product_a8f037501ece7a72a4eabfa2e01c8dd7'] = 'Disponible à la vente';
$_FIELDS['Product_a80df855bb6ec792a6bd2f4260dc7c7d'] = 'Date de disponibilité';
$_FIELDS['Product_3f9178c25b78ed8bed19091bcb62e266'] = 'Condition';
$_FIELDS['Product_f502f8d11a77413b4f273cd601f2b363'] = 'affichage du prix';
$_FIELDS['Product_a3b6a4d0897451813950029a3066f219'] = 'EAN 13';
$_FIELDS['Product_2f9e567efb6a38663162f65eaac2d73b'] = 'UPC';
$_FIELDS['Product_7efb96e1de8fcda98dee6e2a29a521f0'] = 'indexé';
$_FIELDS['Product_21597fd76e73b8c9ee8255fa26c35c80'] = 'cache_is_pack';
$_FIELDS['Product_cfeadf6a60808e5ffeff8268bec49bb6'] = 'is_virtual';
$_FIELDS['Product_98f3e6fb2a32fce35b5243f090cb4b87'] = 'cache_has_attachments';
$_FIELDS['Product_ab332097a7a287c9e711aba495c44e9e'] = 'date d\'ajout';
$_FIELDS['Product_6e3005e36b07fd014f7123b0fe039628'] = 'date de modification';
$_FIELDS['Product_1d549d55228eafc5a0d8b4e9e46b1692'] = 'gestion avancé des stocks';
$_FIELDS['Product_daed73073d15e0baf1cdfaea3b5e28ab'] = 'meta description';
$_FIELDS['Product_69a2fc764784fa41975b85e0aa96ded3'] = 'meta mots-clefs';
$_FIELDS['Product_493c8b960a4aca4d102deaf489d5b3f4'] = 'balise <title>';
$_FIELDS['Product_a2c6a4f5547c18f5b19a2a89569ab4e5'] = 'URL simplifiée';
$_FIELDS['Product_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['Product_67daf92c833c41c95db874e18fcb2786'] = 'description';
$_FIELDS['Product_0f7431650cc1691fbe92dc2cbb70e476'] = 'description courte';
$_FIELDS['Product_b00f6b4f92d22056f98d0c5e72367a4c'] = 'disponibilité immédiate';
$_FIELDS['Product_7ebd308f48331aecb63ddc9dc0f1b9b8'] = 'disponibilité future';
$_FIELDS['Profile_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['QuickAccess_2a304a1348456ccd2234cd71a81bd338'] = 'lien';
$_FIELDS['QuickAccess_48df2d0e8fcf6f9fe7809d5ea0cd2691'] = 'nouvelle_fenêtre';
$_FIELDS['QuickAccess_b068931cc450442b63f5b3d276ea4297'] = 'nom';
$_FIELDS['SpecificPriceRule_b068931cc450442b63f5b3d276ea4297'] = 'Nom';
$_FIELDS['SpecificPriceRule_dc99776458b68786a9e903854e23a483'] = 'A partir de la quantité';
$_FIELDS['SpecificPriceRule_9477e24c78f1ca8ee9b03111f6227fc2'] = 'Réduction';
$_FIELDS['SpecificPriceRule_06d76e815de4d1c0f6d1919068ad54ca'] = 'Type de réduction';
$_FIELDS['SpecificPriceRule_d98a07f84921b24ee30f86fd8cd85c3c'] = 'A partir de';
$_FIELDS['SpecificPriceRule_01b6e20344b68835c5ed1ddedf20d531'] = 'Jusqu\'à';
$_FIELDS['Tab_672070865d6470b0b9c251e275faaa30'] = 'ID de l\'onglet mère';
$_FIELDS['Tab_4757fe07fd492a8be0ea6a760d683d6e'] = 'position';
$_FIELDS['Tab_22884db148f0ffb0d830ba431102b0b5'] = 'module';
$_FIELDS['Tab_c76a5e84e4bdee527e274ea30c680d79'] = 'actif';
$_FIELDS['Tab_b068931cc450442b63f5b3d276ea4297'] = 'nom';

?>
